Welcome to nider's documentation!
=================================

Nider is an approach to make generation of text based images simple yet flexible.

.. toctree::
   :maxdepth: 2

   installation
   usage
   Full API reference <nider>
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
